@@ -14,6 +14,7 @@ from __future__ import absolute_import
 
 # configure Bokeh version
 from .util.version import __version__; __version__
+from .util.version import __base_version__; __base_version__
 
 # configure Bokeh logger
 from .util import logconfig
@@ -23,4 +24,8 @@ del logconfig
 # module as transitive imports
 
 from . import sampledata; sampledata
-from .util.testing import runtests as test; test
+
+
+def test(args=None):
+    from .util.testing import runtests
+    return runtests(args)
