@@ -13,7 +13,9 @@
 # Imports
 #-----------------------------------------------------------------------------
 
-import unittest
+from __future__ import absolute_import
+
+import pytest
 
 from bokeh.charts._builder import Builder
 
@@ -21,9 +23,12 @@ from bokeh.charts._builder import Builder
 # Classes and functions
 #-----------------------------------------------------------------------------
 
-class TestBuilder(unittest.TestCase):
-    def setUp(self):
-        self.builder = Builder([], palette=['red', 'green'])
 
-    def test_instantiate(self):
-        self.builder.palette = ['red', 'green']
+@pytest.fixture
+def builder():
+    return Builder()
+
+
+def test_empty_builder(builder):
+    assert builder.xlabel is None
+
