@@ -5,13 +5,15 @@ with data columns from data sources.
 """
 from __future__ import absolute_import
 
-from ..plot_object import PlotObject
-from ..mixins import FillProps, LineProps, TextProps
 from ..enums import Direction, Anchor
-from ..properties import AngleSpec, Bool, DistanceSpec, Enum, Include, Instance, NumberSpec, StringSpec
+from ..mixins import FillProps, LineProps, TextProps
+from ..plot_object import PlotObject
+from ..properties import (abstract, AngleSpec, Bool, DistanceSpec, Enum, Float,
+                          Include, Instance, NumberSpec, StringSpec)
 
 from .mappers import LinearColorMapper
 
+@abstract
 class Glyph(PlotObject):
     """ Base class for all glyphs/marks/geoms/whatever-you-call-'em in Bokeh.
 
@@ -464,6 +466,10 @@ class ImageURL(Glyph):
     horizontal.
     """)
 
+    global_alpha = Float(1.0, help="""
+    The opacity that each image is rendered with.
+    """)
+
     dilate = Bool(False, help="""
     Whether to always round fractional pixel locations in such a way
     as to make the images bigger.
