@@ -5,8 +5,10 @@ of plots.
 from __future__ import absolute_import
 
 from ..plot_object import PlotObject
+from ..properties import abstract
 from ..properties import Int, Float, Seq, Instance
 
+@abstract
 class Ticker(PlotObject):
     """ A base class for all ticker types. ``Ticker`` is
     not generally useful to instantiate on its own.
@@ -138,4 +140,4 @@ class CategoricalTicker(Ticker):
 class DatetimeTicker(Ticker):
     """ Generate nice ticks across different date and time scales.
 
-    """
\ No newline at end of file
+    """
