@@ -1,8 +1,17 @@
-import flask
+#-----------------------------------------------------------------------------
+# Copyright (c) 2012 - 2015, Continuum Analytics, Inc. All rights reserved.
+#
+# Powered by the Bokeh Development Team.
+#
+# The full license is in the file LICENSE.txt, distributed with this software.
+#-----------------------------------------------------------------------------
+from __future__ import absolute_import
+
 from os import walk
 from os.path import join
 
 from bokeh.settings import settings
+import flask
 
 class BokehBlueprint(flask.Blueprint):
 
@@ -36,7 +45,7 @@ bokeh_app = BokehBlueprint(
     'bokeh.server',
     static_folder='static',
     static_url_path='/bokeh/static',
-    template_folder='templates'
+    template_folder='_templates'
 )
 
 app = flask.Flask("bokeh.server")
