@@ -1,13 +1,20 @@
+#-----------------------------------------------------------------------------
+# Copyright (c) 2012 - 2015, Continuum Analytics, Inc. All rights reserved.
+#
+# Powered by the Bokeh Development Team.
+#
+# The full license is in the file LICENSE.txt, distributed with this software.
+#-----------------------------------------------------------------------------
+from __future__ import absolute_import
 
 import uuid
 
+from bokeh.exceptions import DataIntegrityException, UnauthorizedException
 from six import string_types
 from werkzeug import generate_password_hash, check_password_hash
 
-from bokeh.exceptions import DataIntegrityException
-
 from .docs import Doc
-from .. import models
+from .server_model import ServerModel
 
 def apiuser_from_request(app, request):
     apikey = request.headers.get('BOKEHUSER-API-KEY')
@@ -15,6 +22,8 @@ def apiuser_from_request(app, request):
         return None
     username = request.headers['BOKEHUSER']
     bokehuser = User.load(app.servermodel_storage, username)
+    if bokehuser is None:
+        return None
     if bokehuser.apikey == apikey:
         return bokehuser
     else:
@@ -34,15 +43,15 @@ def new_user(client, username, password, apikey=None, docs=None):
 def auth_user(client, username, password=None, apikey=None):
     user = User.load(client, username)
     if user is None:
-        raise models.UnauthorizedException
+        raise UnauthorizedException
     if password and check_password_hash(user.passhash, password):
         return user
     elif apikey and user.apikey == apikey:
         return user
     else:
-        raise models.UnauthorizedException
+        raise UnauthorizedException
 
-class User(models.ServerModel):
+class User(ServerModel):
     idfield = 'username'
     typename = 'user'
     #we're using username as the id for now...
@@ -68,8 +77,10 @@ class User(models.ServerModel):
         for doc in docs:
             if isinstance(doc, string_types):
                 doc = Doc.load(client, doc)
-                newdocs.append({'title' : doc.title,
-                                'docid' : doc.docid})
+                newdocs.append({
+                    'title' : doc.title,
+                    'docid' : doc.docid
+                })
                 changed = True
             else:
                 newdocs.append(doc)
@@ -93,20 +104,24 @@ class User(models.ServerModel):
 
 
     def to_public_json(self):
-        return {'username' : self.username,
-                'docs' : self.docs}
+        return {
+            'username' : self.username,
+            'docs'     : self.docs
+        }
 
     def to_json(self):
-        return {'username' : self.username,
-                'passhash' : self.passhash,
-                'apikey' : self.apikey,
-                'docs' : self.docs,
-                }
+        return {
+            'username' : self.username,
+            'passhash' : self.passhash,
+            'apikey'   : self.apikey,
+            'docs'     : self.docs,
+        }
 
     @staticmethod
     def from_json(obj):
-        return User(obj['username'],
-                    obj['passhash'],
-                    obj['apikey'],
-                    obj['docs'],
-                    )
+        return User(
+            obj['username'],
+            obj['passhash'],
+            obj['apikey'],
+            obj['docs'],
+        )
