@@ -1,3 +1,10 @@
+#-----------------------------------------------------------------------------
+# Copyright (c) 2012 - 2015, Continuum Analytics, Inc. All rights reserved.
+#
+# Powered by the Bokeh Development Team.
+#
+# The full license is in the file LICENSE.txt, distributed with this software.
+#-----------------------------------------------------------------------------
 """ Utilities for writing plugins.
 
 This is different from bokeh.pluginutils because these are ways of
@@ -6,17 +13,17 @@ would run this type of code using the --script option
 
 """
 
-import uuid
+from __future__ import absolute_import
 
-from flask import abort, render_template
+import uuid
 
 from bokeh.exceptions import DataIntegrityException
 from bokeh.resources import Resources
+from flask import abort, render_template
 
 from ..app import bokeh_app
 from ..views.backbone import init_bokeh
 from ..views.main import _makedoc
-from ..settings import settings as server_settings
 
 def object_page(prefix):
     """ Decorator for a function which turns an object into a web page
@@ -42,6 +49,8 @@ def object_page(prefix):
             bokehuser = bokeh_app.current_user()
             try:
                 doc = _makedoc(bokeh_app.servermodel_storage, bokehuser, docname)
+                doc.published = True
+                doc.save(bokeh_app.servermodel_storage)
             except DataIntegrityException as e:
                 return abort(409, e.message)
             docid = doc.docid
@@ -65,8 +74,7 @@ def object_page(prefix):
                                    objid=obj._id,
                                    hide_navbar=True,
                                    extra_generated_classes=extra_generated_classes,
-                                   splitjs=server_settings.splitjs,
-                                   username=bokehuser.username,
+                                   public='true',
                                    loglevel=resources.log_level)
         wrapper.__name__ = func.__name__
         return wrapper
